@@ -71,6 +71,6 @@ pub fn bench_js_async(
 }
 
 async fn inner_async(src: &str, runtime: &mut JsRuntime) {
-  runtime.execute("inner_loop", src).unwrap();
+  runtime.execute_script("inner_loop", src).unwrap();
   runtime.run_event_loop(false).await.unwrap();
 }
